@@ -47,6 +47,18 @@ def create_job(host, jobname, options):
     if response.status_code == 200 and options.build:
         print('Triggering build.')
         jenkins.build(jobname)
+    print ('Job URL: {0}'.format(jenkins.job_url(jobname)))
+    return response.status_code
+
+
+def build_job(host, jobname):
+    """
+    Trigger build for an existing job
+    """
+    print ("Start building job '{0}'".format(jobname))
+
+    jenkins = Jenkins(host)
+    response = jenkins.build(jobname)
     return response.status_code
 
 
@@ -58,7 +70,7 @@ def delete_job(host, jobname):
 
     jenkins = Jenkins(host)
     response = jenkins.delete(jobname)
-    print('Status: {0}'.format(response.status_code))
+    return response.status_code
 
 
 def list_jobs(host, color=True):
@@ -107,6 +119,18 @@ class Commands:
         else:
             parser.print_help()
 
+    @staticmethod
+    def build():
+        parser = create_opts_parser('build a job')
+
+        (options, args) = parser.parse_args()
+
+        if len(args) == 2:
+            host, jobname = args
+            build_job(host, jobname)
+        else:
+            parser.print_help()
+
     @staticmethod
     def delete():
         parser = create_opts_parser('delete a job')
